rm(list=ls(all=TRUE))
library(RColorBrewer)  
library(sfsmisc)

         k.colors = brewer.pal(6,"Set1")  # Dark2


load("CompiledData_Purob.RData")
treatments.desert = read.csv("treatments_Purob.csv")
tensile_strength_desert = read.csv("desert_soil_tensile_strength.csv")

all_S_P=read.csv('stress_pressure_all.csv')

# Create a sheet for Purob Psi = 0.06 bar
Purob_0.06 <- dat[[treatments.desert$Sheet[55]]][61:1200,1:2]
Purob_0.06$Psi <- 0.06
Purob_0.06$P <- Purob_0.06$P*100
Purob_0.06$t <- Purob_0.06$t-60
Purob_0.06$Temp <- dat[[treatments.desert$Sheet[55]]][61:1200,3]

# Create a sheet for Purob Psi = 0.10 bar
Purob_0.10 <- dat[[treatments.desert$Sheet[51]]][61:1200,1:2]
Purob_0.10$Psi <- 0.10
Purob_0.10$P <- Purob_0.10$P*100
Purob_0.10$t <- Purob_0.10$t-60
Purob_0.10$Temp <- dat[[treatments.desert$Sheet[51]]][61:1200,3]

# Create a sheet for Purob Psi = 0.30 bar
Purob_0.30 <- dat[[treatments.desert$Sheet[4]]][61:1200,1:2]
Purob_0.30$Psi <- 0.30
Purob_0.30$P <- Purob_0.30$P*100
Purob_0.30$t <- Purob_0.30$t-60
Purob_0.30$Temp <- dat[[treatments.desert$Sheet[3]]][61:1200,3]

Purob_1.00 <- dat[[treatments.desert$Sheet[17]]][61:1200,1:2]
Purob_1.00$Psi <- 1.00
Purob_1.00$P <- Purob_1.00$P*100
Purob_1.00$t <- Purob_1.00$t-60
Purob_1.00$Temp <- dat[[treatments.desert$Sheet[32]]][61:1200,3]

Purob_1236.03 <- dat[[treatments.desert$Sheet[34]]][61:1200,1:2]
Purob_1236.03$Psi <- 1236.03
Purob_1236.03$P <- Purob_1236.03$P*100
Purob_1236.03$t <- Purob_1236.03$t-60
Purob_1236.03$Temp <- dat[[treatments.desert$Sheet[37]]][61:1200,3]





# FOREST SOIL ===========  
load("CompiledData.RData")
treatments.forest = read.csv("treatments.csv")
tensile_strength_forest = read.csv("forest_soil_tensile_strength.csv")


# create a spreadsheet for forest aggregates
treatments.forest$psi_kPa = treatments.forest$Psi*100
treatments.forest$max.t  = NA
treatments.forest$max.P  = NA
treatments.forest$max.P_kPa = NA

for(i in 1:82){
  temp=dat[[treatments.forest$Sheet[i]]][61:960,]
  max.P = max(temp$P,na.rm=TRUE)
  max.t = temp$t[which.max(temp$P)]
  treatments.forest$max.t[i]  = max.t
  treatments.forest$max.P[i]  = max.P
  treatments.forest$max.P_kPa[i] = 100*max.P
}

# remove sheet 72 and 74 since I don't trust the data
treatments.forest = treatments.forest[-c(72,74),]

# Create a sheet for Mariposa Psi = 0.06 bar
forest_0.06 <- dat[[treatments.forest$Sheet[10]]][61:1500,1:2]
forest_0.06$Psi <- 0.06
forest_0.06$P <- forest_0.06$P*100
forest_0.06$t <- forest_0.06$t-60
forest_0.06$Temp <- dat[[treatments.forest$Sheet[29]]][61:1500,3]

forest_0.10 <- dat[[treatments.forest$Sheet[41]]][61:1500,1:2]
forest_0.10$Psi <- 0.10
forest_0.10$P <- forest_0.10$P*100
forest_0.10$t <- forest_0.10$t-60
forest_0.10$Temp <- dat[[treatments.forest$Sheet[19]]][61:1500,3]

forest_0.30 <- dat[[treatments.forest$Sheet[1]]][61:1500,1:2]
forest_0.30$Psi <- 0.30
forest_0.30$P <- forest_0.30$P*100
forest_0.30$t <- forest_0.30$t-60
forest_0.30$Temp <- dat[[treatments.forest$Sheet[1]]][61:1500,3]

forest_1.00 <- dat[[treatments.forest$Sheet[58]]][61:1500,1:2]
forest_1.00$Psi <- 1.00
forest_1.00$P <- forest_1.00$P*100
forest_1.00$t <- forest_1.00$t-60
forest_1.00$Temp <- dat[[treatments.forest$Sheet[61]]][61:1500,3]

forest_942.30 <- dat[[treatments.forest$Sheet[78]]][61:1500,1:2]
forest_942.30$Psi <- 942.30
forest_942.30$P <- forest_942.30$P*100
forest_942.30$t <- forest_942.30$t-60
forest_942.30$Temp <- dat[[treatments.forest$Sheet[75]]][61:1500,3]



# FIGURES ==============

pdf("TypicalCurves.pdf",height=6,width=6)
  par(oma=c(2,2,0.5,0.5), mar=c(1,1,0,0), cex=1, las=1)  
  m=matrix(1:4,ncol=2,byrow=FALSE); layout(m)

  plot(NA, xlim=c(0,1200), ylim=c(0,200),axes=FALSE)
  lines(   forest_0.06$t,    forest_0.06$Temp   , col=k.colors[1])
  lines(   forest_0.10$t,    forest_0.10$Temp   , col=k.colors[2])
  lines(   forest_0.30$t,    forest_0.30$Temp   , col=k.colors[3])
  lines(   forest_1.00$t,    forest_1.00$Temp   , col=k.colors[4])
  lines( forest_942.30$t,  forest_942.30$Temp   , col=k.colors[5])
     box()
     axis(1,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE)
     axis(3,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE)
     axis(2,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=TRUE)
     axis(4,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE)
     mtext(expression(paste(Surface~Temperature,', ',degree,'C')), side=2, line=1.7, las=0, outer=FALSE, cex=1)
     text(0,200*0.97,'(a) Forest', adj = c(0, 1))

  plot(NA, xlim=c(0,1200), ylim=c(-0.1,3),axes=FALSE)
  lines(  forest_0.06$t,      forest_0.06$P      , col=k.colors[1])
  lines(  forest_0.10$t,      forest_0.10$P      , col=k.colors[2])
  lines(  forest_0.30$t,      forest_0.30$P      , col=k.colors[3])
  lines(  forest_1.00$t,      forest_1.00$P      , col=k.colors[4])
  lines(forest_942.30$t,    forest_942.30$P      , col=k.colors[5])
     box()
     axis(1,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=TRUE)
     axis(3,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE)
     axis(2,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=TRUE, at=c(0:3))
     axis(4,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE, at=c(0:3))
     text(0,3*0.97,'(c) Forest', adj = c(0, 1))
     mtext(expression(paste(Pore~Pressure,', ',kPa)), side=2, line=1.7, las=0, outer=FALSE, cex=1)

  
  plot(NA, xlim=c(0,1200), ylim=c(0,200),axes=FALSE)
  lines(   Purob_0.06$t,    Purob_0.06$Temp   , col=k.colors[1])
  lines(   Purob_0.10$t,    Purob_0.10$Temp   , col=k.colors[2])
  lines(   Purob_0.30$t,    Purob_0.30$Temp   , col=k.colors[3])
  lines(   Purob_1.00$t,    Purob_1.00$Temp   , col=k.colors[4])
  lines(Purob_1236.03$t, Purob_1236.03$Temp   , col=k.colors[5])
     box()
     axis(1,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE)
     axis(3,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE)
     axis(2,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE)
     axis(4,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE)
     text(0,200*0.97,'(b) Shrubland', adj = c(0, 1))
     
  plot(NA, xlim=c(0,1200), ylim=c(-0.1,3),axes=FALSE)
  lines(   Purob_0.06$t,    Purob_0.06$P      , col=k.colors[1])
  lines(   Purob_0.10$t,    Purob_0.10$P      , col=k.colors[2])
  lines(   Purob_0.30$t,    Purob_0.30$P      , col=k.colors[3])
  lines(   Purob_1.00$t,    Purob_1.00$P      , col=k.colors[4])
  lines(Purob_1236.03$t,    Purob_1236.03$P   , col=k.colors[5])
  
     box()
     axis(1,tck=0.02, cex.axis=1,mgp=c(3, .3, 0))
     axis(3,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE)
     axis(2,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE, at=c(0:3))
     axis(4,tck=0.02, cex.axis=1,mgp=c(3, .3, 0),labels=FALSE, at=c(0:3))
     text(1,39, '(b)', cex=1.5)
     text(0,3*0.97,'(d) Shrubland', adj = c(0, 1))
     mtext('Heating Time, sec', side=1, outer=TRUE, line=.7, cex=1)
     legend(500,2.5,c('6','10','30','100','air-dry'), col=k.colors, lty=1, lwd=2, bty='n',title=expression(paste(psi,' (-kPa)')))

  
dev.off()  

f.P = all_S_P[all_S_P$soil=='Forest'&all_S_P$Measurement=='Maximum pressure', ]
f.S = all_S_P[all_S_P$soil=='Forest'&all_S_P$Measurement=='Tensile strength', ]
s.P = all_S_P[all_S_P$soil=='Shrubland'&all_S_P$Measurement=='Maximum pressure', ]
s.S = all_S_P[all_S_P$soil=='Shrubland'&all_S_P$Measurement=='Tensile strength', ]

p = 10^seq(0.6,5.2,0.1)
pp = 10^seq(0.6,3.5,0.01)
p2 = 10^seq(3.5,5.2,0.1)
py = 10^seq(0.6,2.5,0.01)
f.P.lm = lm(log10(f.P$kPa)~log10(f.P$Psi))
f.S.lm = lm(log10(f.S$kPa)~log10(f.S$Psi)) 

s.P.lm = lm(log10(s.P$kPa)~log10(s.P$Psi)) 
s.S.lm = lm(s.S$kPa[1:4]~log10(s.S$Psi[1:4])) 



# RHEOLOGY-----
f.swc = data.frame(
             psi = c(6, 10, 30, 100,94230),               # kPa
             w   = c(0.413, 0.359, 0.318, 0.311,0.022),     # g/g
             w.se= c(0.009, 0.015, 0.024, 0.0024,0.00)     # g/g
             )

s.swc = data.frame(
             psi = c(6, 10, 30, 100,94230),               # kPa
             w   = c(0.195, 0.180, 0.174, 0.138,0.024),     # g/g
             w.se= c(0.009, 0.015, 0.024, 0.0024,0.00)     # g/g
             )

# Milville
   a.visc    = -7.43
   a.yield   = -8.19
   visc.0    = 5.702
   yield.0   = 0.0439 

f.yield = sqrt(3)*yield.0 * f.swc$w^a.yield
s.yield = sqrt(3)*yield.0*(1/1) * s.swc$w^a.yield   

f.Y.lm = lm(log10(f.yield[-5])~log10(f.swc$psi[-5]))
s.Y.lm = lm(log10(s.yield[-5])~log10(s.swc$psi[-5]))


pdf("Stress_Strength.pdf",height=4,width=6)
  par(oma=c(2,2.5,0.5,0.5), mar=c(1,1,0,0), cex=1, las=1)  
  m=matrix(1:2,ncol=2,byrow=FALSE); layout(m)
  
  plot(NA, xlim=c(5,200000),ylim=c(0.1,200), log='xy', axes=FALSE)
   lines(p, 10^(coef(f.P.lm)[1] + log10(p)*coef(f.P.lm)[2]), lty=1)
     arrows(f.P$Psi,f.P$kPa-f.P$kPa.se, f.P$Psi, f.P$kPa+f.P$kPa.se, angle=90, length=0.02, code=3 )
   points(f.P$Psi, f.P$kPa, pch=22, cex=0.8, bg='gray10')
     text(10000,0.5,bquote(bold(R^2 == .(format(summary(f.P.lm)$r.squared, digits=3))))   ,cex=0.8)

  lines(p, 10^(coef(f.S.lm)[1] + log10(p)*coef(f.S.lm)[2]), lty=1)
      arrows(f.S$Psi,f.S$kPa-f.S$kPa.se, f.S$Psi, f.S$kPa+f.S$kPa.se, angle=90, length=0.02, code=3 )
  points(f.S$Psi, f.S$kPa, pch=23, cex=0.8, bg='white')
  
  points(f.swc$psi, f.yield/1000, pch=21, cex=0.8, bg='white')
  lines(py, (10^(coef(f.Y.lm)[1] + log10(py)*coef(f.Y.lm)[2]))/1000, lty=2)
  
     text(50000,25,bquote(bold(R^2 == .(format(summary(f.S.lm)$r.squared, digits=3)))) ,cex=0.8)  
     
  text(5,199,'(a) Forest Soil', adj = c(0, 1))
  box()
  eaxis(1, tck=0.02, cex.axis=1,mgp=c(3, .3, 0), f.smalltcl=0)
  eaxis(2, tck=0.02, cex.axis=1,mgp=c(3, .3, 0),at = c(0.1,1,10,100), f.smalltcl=0)
  eaxis(4, tck=0.02, cex.axis=1,mgp=c(3, .3, 0),at = c(0.1,1,10,100), f.smalltcl=0,labels=FALSE)
  legend(5,100,c('Peak Pressure','Tensile Strength', 'Yield Stress'), lty = c(1,1,20), pch=c(22,23,21), pt.bg=c('gray10','white','white'), cex=0.7, pt.cex=1)
  
  plot(NA, xlim=c(5,200000),ylim=c(0.1,200), log='xy', axes=FALSE)
  lines(p, 10^(coef(s.P.lm)[1] + log10(p)*coef(s.P.lm)[2]), lty=1)
     arrows(s.P$Psi,s.P$kPa-s.P$kPa.se, s.P$Psi, s.P$kPa+s.P$kPa.se, angle=90, length=0.02, code=3 )
  points(s.P$Psi, s.P$kPa, pch=22, cex=0.8, bg='gray10')
     text(10000,1,bquote(bold(R^2 == .(format(summary(s.P.lm)$r.squared, digits=3))))   ,cex=0.8)
  lines(pp, (coef(s.S.lm)[1] + log10(pp)*coef(s.S.lm)[2]), lty=1)
  lines(p2, (coef(s.S.lm)[1] + log10(p2)*coef(s.S.lm)[2]), lty=3)
      arrows(s.S$Psi,s.S$kPa-s.S$kPa.se, s.S$Psi, s.S$kPa+s.S$kPa.se, angle=90, length=0.02, code=3 )
  points(s.S$Psi, s.S$kPa, pch=23, cex=0.8, bg='white')
  lines(py, (10^(coef(s.Y.lm)[1] + log10(py)*coef(s.Y.lm)[2]))/1000, lty=2)
  
    points(s.swc$psi, s.yield/1000, pch=21, cex=0.8, bg='white')

  
  text(500,199,'(b) Shrubland Soil', adj = c(0, 1))
     text(100,30,bquote(bold(R^2 == .(format(summary(s.S.lm)$r.squared, digits=3)))) ,cex=0.8)  
     
  box()
  eaxis(1,tck=0.02, cex.axis=1,mgp=c(3, .3, 0), f.smalltcl=0)
  eaxis(2, tck=0.02, cex.axis=1,mgp=c(3, .3, 0),at = c(0.1,1,10,100), labels=FALSE, f.smalltcl=0)
  
       mtext('Matric Potential (-kPa)', side=1, outer=TRUE, line=.7, cex=1)
       mtext('Peak Pressure or Tensile Strength', side=2, outer=TRUE, line=1.5, cex=1, las=0)
       mtext('or Yield Stress (kPa)', side=2, outer=TRUE, line=0.5, cex=1, las=0)

  dev.off()
