rm(list=ls(all=TRUE))
library(RColorBrewer)  
library(sfsmisc)
library(plyr)

         k.colors = brewer.pal(6,"Set1")  # Dark2
# FOREST SOIL ===========  
load("CompiledData.RData")
treatments.forest = read.csv("treatments.csv")
tensile_strength_forest = read.csv("forest_soil_tensile_strength.csv")

dat.forest=dat

# remove sheet 72 and 74 since I don't trust the data
treatments.forest = treatments.forest[-c(72,74),]
dat.forest = dat.forest[-c(72,74)]

forest.swc = data.frame(
             psi = c(6, 10, 30, 100,94230),               # kPa
             w   = c(0.413, 0.359, 0.318, 0.311,0.00022),     # g/g
             w.se= c(0.009, 0.015, 0.024, 0.0024,0.00)     # g/g
             )

swc.fun = approxfun(forest.swc$w[-5], log(forest.swc$psi[-5]))

x = seq(0.311, 0.413,0.001)

plot(forest.swc$w[-5], log(forest.swc$psi[-5]))
lines(x, swc.fun(x))

treatments.forest = treatments.forest[order(treatments.forest$Psi),]

treatments.forest$w = 0
for (i in 1:nrow(forest.swc)){
  treatments.forest$w[which(treatments.forest$Psi==forest.swc$psi[i]/100)] = forest.swc$w[i]
}

for (i in 1:nrow(forest.swc)){
  
  sheets = which(treatments.forest$Psi==forest.swc$psi[i]/100)
  print(forest.swc$psi[i]/100)
  print(sheets)
  plot(NA, xlim=c(0,1000), ylim=c(0,10))
  for (j in 1:length(sheets)){
    temp = dat.forest[[sheets[j]]][1:960,]
    m = treatments.forest$Mass[sheets[j]]
    lines((P*100/m)~t, data=temp, col=j)
    cat(j, ' ')
  }
  cat('\n')
  title(forest.swc$psi[i]/100)
}



# RHEOLOGY MODEL FOREST ------------------

k.forest     = 3.76e-3
k.forest.se  = 1.12e-3   # sec^-1
# Milville
   a.visc    = -7.43
   a.yield   = -8.19
   visc.0    = 5.702
   yield.0   = 0.0439 

   # Fraternidad
   # a.visc    = -5.61
   # a.yield   = -3.753
   # visc.0    = 313.5
   # yield.0   = 481 


   
yield = sqrt(3)*yield.0 * forest.swc$w[-5]^a.yield

plot(forest.swc$psi[-5], yield/1000, log='xy')

treatments.forest$S.m = 0
treatments.forest$S.p = 0
treatments.forest$S   = 0

strain = function(t, P, a.visc, a.yield, visc.0, yield.0,w.0,k){
  P = P * 1000   # pressure in Pa
  w = w.0 * exp(-k*t)
  Y = sqrt(3)*yield.0 * w^a.yield
  P.net = P*0
  for (i in 1:length(P)){
    if(P[i]>Y[i]) P.net[i] = P[i]-Y[i]
  }
  d.gamma = P.net/(visc.0*w^a.visc)
  gamma = cumsum(d.gamma)
}

    plot(NA, xlim=c(1,100), ylim=c(0.001,10),log='xy', axes=FALSE)
for (i in 1:nrow(forest.swc)){
  
  sheets = which(treatments.forest$Psi==forest.swc$psi[i]/100)
  w.m = forest.swc$w - forest.swc$w.se
  w.p = forest.swc$w + forest.swc$w.se
  w   = forest.swc$w 
  
  for (j in 1:length(sheets)){
    temp = dat.forest[[sheets[j]]][61:960,]
    X.m = strain(temp$t, temp$P*100, a.visc, a.yield, visc.0, yield.0, w.m, k.forest-k.forest.se/1.)
    X.p = strain(temp$t, temp$P*100, a.visc, a.yield, visc.0, yield.0, w.p, k.forest-k.forest.se/1.)
    X   = strain(temp$t, temp$P*100, a.visc, a.yield, visc.0, yield.0, w  , k.forest-k.forest.se/1.)
    m = treatments.forest$Mass[sheets[j]]
    points(forest.swc$psi[i], max(X), col=i, cex=1.5, pch=2)
    if(max(X)>0) {
      treatments.forest$S.m[sheets[j]]  = max(X.m)
      treatments.forest$S.p[sheets[j]]  = max(X.p)
      treatments.forest$S[sheets[j]]    = max(X)
    }
  }
  
}
eaxis(1)
eaxis(2)

plot(treatments.forest$Psi,treatments.forest$S*treatments.forest$Mass, log='x')

treatments.forest$Treatment = factor(treatments.forest$Psi)

boxplot(S~Treatment, data = treatments.forest)

treatments.forest.sub = treatments.forest[!is.na(treatments.forest$S),]
X.sum<- ddply(treatments.forest,c("Treatment"), summarise,
                               N = length(S>0),
                               mean = mean(S, na.rm=TRUE),
                               sd = sd(S, na.rm=TRUE),
                               se = sd/sqrt(N)
              )
X.sum.m<- ddply(treatments.forest,c("Treatment"), summarise,
                               N = length(S.m>0),
                               mean = mean(S.m, na.rm=TRUE),
                               sd = sd(S.m, na.rm=TRUE),
                               se = sd/sqrt(N)
              )
X.sum.p<- ddply(treatments.forest,c("Treatment"), summarise,
                               N = length(S.p>0),
                               mean = mean(S.p, na.rm=TRUE),
                               sd = sd(S.p, na.rm=TRUE),
                               se = sd/sqrt(N)
              )


X.sum$P   = c(6,10,30,100,100000)
X.sum.m$P = c(6,10,30,100,100000)
X.sum.p$P = c(6,10,30,100,100000)
X.sum$w = forest.swc
pdf("ViscStrain.pdf",height=3.5,width=3.5)
  par(oma=c(2,2,0.5,0.5), mar=c(1,1,0,0), cex=1, las=1)  
  m=matrix(1:1,ncol=2,byrow=FALSE); layout(m)

  plot(NA, ylim=c(0,0.1), xlim=c(0,110), axes=FALSE)
  arrows(X.sum$P,  X.sum$mean-X.sum$se, X.sum$P, X.sum$mean+X.sum$se, length=0.05,angle=90,code=3)
  points(X.sum$P,  X.sum$mean, pch=23, bg='white')
  #points(X.sum.m$P,X.sum.m$mean, pch=23, bg='white', col=2)
  #points(X.sum.p$P,X.sum.p$mean, pch=23, bg='white', col=3)
  eaxis(1, tck=0.02,  cex.axis=1,mgp=c(3, .3, 0), f.smalltcl=0, at=seq(0,100,20))
  eaxis(2, tck=0.02, cex.axis=1,mgp=c(3, .3, 0), at =c(0,0.05, 0.1, 0.15,0.2), f.smalltcl=0)
  #abline(h=0, lty=3, col='gray80')
  box()
      mtext('Matric Potential (-kPa)', side=1, outer=TRUE, line=.7, cex=1)
       mtext('Approx. Viscoplastic Strain', side=2, outer=TRUE, line=1, cex=1, las=0)

dev.off()
#stop()